pub enum VoltError {
Show 20 variants
Io(Error),
RecvError(RecvError),
ExecuteFail(VoltResponseInfo),
InvalidColumnType(i8),
MessageTooLarge(usize),
NoValue(String),
Other(String),
NegativeNumTables(i16),
Utf8Error(Utf8Error),
PoisonError(String),
BadReturnStatusOnTable(i8),
AuthFailed,
ConnectionNotAvailable,
InvalidConfig,
Timeout,
ConnectionClosed,
UnexpectedNull(String),
PoolShutdown,
CircuitOpen,
PoolExhausted,
}Expand description
The single error type for all VoltDB client operations.
Variants
Io(Error)
RecvError(RecvError)
ExecuteFail(VoltResponseInfo)
InvalidColumnType(i8)
MessageTooLarge(usize)
NoValue(String)
Other(String)
NegativeNumTables(i16)
Utf8Error(Utf8Error)
PoisonError(String)
BadReturnStatusOnTable(i8)
AuthFailed
ConnectionNotAvailable
InvalidConfig
Timeout
ConnectionClosed
UnexpectedNull(String)
Returned when a non-Option type encounters a NULL value.
Use Option<T> if the column may contain NULL values.
PoolShutdown
CircuitOpen
PoolExhausted
Implementations
Sourceimpl VoltError
impl VoltError
Sourcepub fn is_connection_fatal(&self) -> bool
pub fn is_connection_fatal(&self) -> bool
Returns true if this error indicates a fatal connection problem that requires the connection to be replaced/healed.
pub fn message_too_large(size: usize) -> Self
pub fn connection_closed() -> Self
pub fn timeout() -> Self